<?php

function andrina_two_columns_blog_pattern() {
	wp_enqueue_style( 'andrina-gridblogwidget', ANDRINA_DIR_URI . "/includes/widgets/2-columns-pattern/2-columns-pattern.css", '', '', 'all' );
}

add_action( 'wp_enqueue_scripts', 'andrina_two_columns_blog_pattern' );

class two_columns_blog_pattern_widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' => 'two_columns_blog_pattern_widget',
			'description' => 'This widget enables the two_columns type blog pattern on the home page.',
		);
		parent::__construct( 'two_columns_blog_pattern_widget', 'Two Columns Blog Pattern', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
//		 outputs the content of the widget
		echo $args['before_widget'];
		if ( !empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		$_max = $instance['numb_post'];
		$paged = (get_query_var( 'paged' )) ? get_query_var( 'paged' ) : 1;
		// WP_Query arguments
		?>
		<div class="row">
			<div class="col-md-6">
				<?php
				$blog_args = array(
					'post_type' => array( 'post' ),
					'post_status' => array( 'publish' ),
					'paged' => $paged,
					'cat' => $instance['left_category'],
					'posts_per_page' => $_max,
				);
				$query = new WP_Query( $blog_args );
				if ( $query->have_posts() ) {
					while ( $query->have_posts() ) {
						$query->the_post();
						get_template_part( 'templates/home', 'content-two-columns-pattern' );
					}
				}
				?>
			</div>
			<div class="col-md-6">
				<?php
				$blog_args = array(
					'post_type' => array( 'post' ),
					'post_status' => array( 'publish' ),
					'paged' => $paged,
					'cat' => $instance['right_category'],
					'posts_per_page' => $_max,
				);
				$query = new WP_Query( $blog_args );

				if ( $query->have_posts() ) {
					while ( $query->have_posts() ) {
						$query->the_post();
						get_template_part( 'templates/home', 'content-two-columns-pattern' );
					}
				}
				?>
			</div>
		</div>
		<?php
		wp_reset_query();

		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		$title = !empty( $instance['title'] ) ? $instance['title'] : __( 'Blog Posts', 'andrina-lite' );
		$numb_post = !empty( $instance['numb_post'] ) ? $instance['numb_post'] : 9;
		$left_category = !empty( $instance['left_category'] ) ? $instance['left_category'] : '';
		$right_category = !empty( $instance['right_category'] ) ? $instance['right_category'] : '';
//		echo category;
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'andrina-lite' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'numb_post' ); ?>"><?php _e( 'Number Of Post:', 'andrina-lite' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'numb_post' ); ?>" name="<?php echo $this->get_field_name( 'numb_post' ); ?>" type="text" value="<?php echo esc_attr( $numb_post ); ?>">
		</p>
		<p>
			<label for="<?php echo $this->get_field_name( 'left_category' ); ?>"><?php _e( 'Left Category:', 'andrina-lite' ); ?></label>
			<?php wp_dropdown_categories( array( 'name' => $this->get_field_name( 'left_category' ), 'selected' => $left_category ) ); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_name( 'right_category' ); ?>"><?php _e( 'Right Category:', 'andrina-lite' ); ?></label>
			<?php wp_dropdown_categories( array( 'name' => $this->get_field_name( 'right_category' ), 'selected' => $right_category ) ); ?>
		</p>
		<?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title'] = (!empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['numb_post'] = (!empty( $new_instance['numb_post'] ) ) ? strip_tags( $new_instance['numb_post'] ) : '9';
		$instance['left_category'] = (!empty( $new_instance['left_category'] ) ) ? strip_tags( $new_instance['left_category'] ) : '';
		$instance['right_category'] = (!empty( $new_instance['right_category'] ) ) ? strip_tags( $new_instance['right_category'] ) : '';
		return $instance;
	}

}

add_action( 'widgets_init', function() {
	register_widget( 'two_columns_blog_pattern_widget' );
} );
